@@ -19,17 +19,20 @@ import os
 import sys
 import Queue
 import threading
+import string
+import random
+
 from ConfigParser import ConfigParser
 import logging.handlers
 
-from modules.HTTP import util
+from modules.HTTP.handler import HTTPHandler
 import modules.HTTP.method_handler as method_handler
 import modules.events.attack as attack
 from modules.handlers.request_handler import RequestHandler
 from modules import logging_handler
 import shutil
 import modules.privileges as privileges
-import modules.processing.profiler as profiler
+#import modules.processing.profiler as profiler
 from modules.handlers.emulators.dork_list import dork_file_processor
 from modules.handlers.emulators.dork_list import database_sqla
 from modules.handlers.emulators.dork_list import database_mongo
@@ -71,12 +74,12 @@ class GlastopfHoneypot(object):
             logger.info("Generating initial dork pages - this can take a while.")
             self.dork_generator.regular_generate_dork(0)
 
-        #hmm?
+        #profiler disabled until issue #26 is fixed
         self.profiler_available = False
         if self.profiler_available:
             self.profiler = profiler.Profiler(self.maindb)
 
-        self.HTTP_parser = util.HTTPParser()
+        #self.HTTP_parser = util.HTTPParser()
         self.MethodHandlers = method_handler.HTTPMethods(self.data_dir)
 
         #used for post processing (logging and analysis) of attack events
@@ -89,7 +92,7 @@ class GlastopfHoneypot(object):
         """
         privileges.drop(self.work_dir, self.options['uid'], self.options['gid'])
         self.workers_enabled = True
-        self.loggers = logging_handler.get_aux_loggers()
+        self.loggers = logging_handler.get_aux_loggers(self.data_dir)
 
         dork_thread = threading.Thread(
             target=self.dork_generator.regular_generate_dork, args=(30,))
@@ -156,7 +159,6 @@ class GlastopfHoneypot(object):
                 sqla_engine = create_engine(connection_string)
                 maindb = log_sql.Database(sqla_engine)
                 dorkdb = database_sqla.Database(sqla_engine)
-                self.profiler_available = True
                 return (maindb, dorkdb)
             else:
                 logger.error("Invalid connection string.")
@@ -168,10 +170,60 @@ class GlastopfHoneypot(object):
             sqla_engine = create_engine("sqlite://db/glastopf.db")
             maindb = log_sql.Database(sqla_engine)
             dorkdb = database_sqla.Database(sqla_engine)
-            self.profiler_available = True
             #disable usage of main logging datbase
             return (None, dorkdb)
 
+    @staticmethod
+    def _get_entry(user_id):
+        # Random username of 3 characters
+        name = "".join([random.choice(string.letters[:26]) for i in xrange(3)])
+        gid = user_id
+        uid = user_id
+        g = "\n" + name + ":x:" + str(gid) + ":"
+        p = "\n" + name + ":x:" + str(uid) + ":" + str(gid) + "::" + "/home/" + name + \
+            "/:/bin/sh"
+        # If we want to, we could also give a password hash in place of '*'
+        s = "\n" + name + ":*:6723:0:99999:7:::"
+        return p, s, g
+
+    @staticmethod
+    def randomize_vdocs(vpath):
+        # For now, we'll only change the passwd, shadow and group files.
+        pwd_path = os.path.join(vpath, 'linux/etc/passwd')
+        shd_path = os.path.join(vpath, 'linux/etc/shadow')
+        grp_path = os.path.join(vpath, 'linux/etc/group')
+
+        num_entries = random.randint(1, 10) # number of random entries
+
+        pwd = open(pwd_path, "a")
+        shd = open(shd_path, "a")
+        grp = open(grp_path, "a")
+        for i in xrange(num_entries):
+            # Possible duplication of user id, but very low probability
+            user_id = random.randint(1000, 1500)
+            pwd_entry, shd_entry, grp_entry = GlastopfHoneypot._get_entry(user_id)
+
+            pwd.write(pwd_entry)
+            shd.write(shd_entry)
+            grp.write(grp_entry)
+        pwd.close()
+        shd.close()
+        grp.close()
+
+    @staticmethod
+    def prepare_sandbox(work_dir):
+        logger.info('Creating PHP sandbox')
+        #create sandbox
+        sandbox_dir = os.path.join(package_directory, 'sandbox')
+        #preserve old working dir
+        old_cwd = os.getcwd()
+        os.chdir(sandbox_dir)
+        #execute makefile and output to self.workdir/data/apd_sandbox.php
+        sandbox_out = os.path.join(work_dir, 'data', 'sandbox.php')
+        check_call(['make', '-B', '-s', 'out={0}'.format(sandbox_out)])
+        #restore state of original working dir
+        os.chdir(old_cwd)
+
     @staticmethod
     def prepare_environment(work_dir):
         """
@@ -197,32 +249,29 @@ class GlastopfHoneypot(object):
 
         #copy emulator level data
         emulator_data_dir = os.path.join(package_directory, 'modules/handlers/emulators/data/')
-        shutil.copytree(emulator_data_dir, os.path.join(work_dir, 'data/'))
+
+        shutil.copytree(emulator_data_dir, os.path.join(work_dir, 'data/'),
+                        ignore=GlastopfHoneypot._ignore_copy_files)
 
         dirs = ('log', 'db', 'files', 'data')
         for entry in dirs:
             dir_path = os.path.join(work_dir, entry)
             if not os.path.isdir(dir_path):
                 os.mkdir(dir_path)
-
+            # Randomize the files in virtualdocs folder
+        GlastopfHoneypot.randomize_vdocs(os.path.join(work_dir, 'data/virtualdocs/'))
         GlastopfHoneypot.prepare_sandbox(work_dir)
 
     @staticmethod
-    def prepare_sandbox(work_dir):
-        logger.info('Creating PHP sandbox')
-        #create sandbox
-        sandbox_dir = os.path.join(package_directory, 'sandbox')
-        #preserve old working dir
-        old_cwd = os.getcwd()
-        os.chdir(sandbox_dir)
-        #execute makefile and output to self.workdir/data/apd_sandbox.php
-        sandbox_out = os.path.join(work_dir, 'data', 'sandbox.php')
-        check_call(['make', '-B', '-s', 'out={0}'.format(sandbox_out)])
-        #restore state of original working dir
-        os.chdir(old_cwd)
+    def _ignore_copy_files(path, content):
+        to_ignore = []
+        for file in content:
+            if file in ('.placeholder', '.git'):
+                to_ignore.append(file)
+        return to_ignore
 
     def _handle_proxy(self, attack_event, addr):
-        client_ip = attack_event.parsed_request.header['X-Forwarded-For']
+        client_ip = attack_event.http_request.header['X-Forwarded-For']
         client_ip = client_ip.split(',')[-1]
         if client_ip == 'unknown':
             client_ip = '0.0.0.0'
@@ -230,44 +279,38 @@ class GlastopfHoneypot(object):
         attack_event.source_addr = (client_ip, addr[1])
 
     def handle_request(self, raw_request, addr, connection):
-        response_code = "200 OK"
-        attack_event = attack.AttackEvent()
-        #attack_event.sensor_addr = connection.sock.getsockname()
-        attack_event.raw_request = raw_request
-        # Parse the request
-        try:
-            attack_event.parsed_request = self.HTTP_parser.parse_request(
-                raw_request)
-        except util.ParsingError as e:
-            response_code = e.response_code
-        else:
-            if self.options["proxy_enabled"] == "True":
-                self._handle_proxy(attack_event)
-            else:
-                attack_event.source_addr = addr
-            logger.info("{0} requested {1} {2} on {3}".format(
-                attack_event.source_addr[0],
-                attack_event.parsed_request.method,
-                attack_event.parsed_request.url,
-                attack_event.parsed_request.header.get('Host', "None")
-            )
-            )
-            # Handle the HTTP request method
-            attack_event.matched_pattern = getattr(
-                self.MethodHandlers,
-                attack_event.parsed_request.method,
-                self.MethodHandlers.GET
-            )(attack_event.parsed_request)
-            # Handle the request with the specific vulnerability module
-            request_handler = RequestHandler(os.path.join(self.work_dir, 'data/'))
-            emulator = request_handler.get_handler(attack_event.matched_pattern)
-            emulator.handle(attack_event)
-            # Logging the event
-            if self.profiler_available:
-                self.profiler.handle_event(attack_event)
-            self.post_queue.put(attack_event)
-            response_code = "200 OK"
-        response_util = util.HTTPServerResponse(response_code)
-        attack_event.response = response_util.get_header(attack_event) + attack_event.response
-        return attack_event.response
 
+        attack_event = attack.AttackEvent()
+        attack_event.raw_request = raw_request
+
+        attack_event.http_request = HTTPHandler(raw_request, addr)
+
+        if self.options["proxy_enabled"] == "True":
+            self._handle_proxy(attack_event)
+        else:
+            attack_event.source_addr = addr
+        logger.info("{0} requested {1} {2} on {3}".format(
+            attack_event.source_addr[0],
+            attack_event.http_request.command,
+            attack_event.http_request.path,
+            attack_event.http_request.headers.get('Host', "None")
+        )
+        )
+        # Handle the HTTP request method
+        attack_event.matched_pattern = getattr(
+            self.MethodHandlers,
+            attack_event.http_request.command,
+            self.MethodHandlers.GET
+        )(attack_event.http_request)
+        # Handle the request with the specific vulnerability module
+        request_handler = RequestHandler(os.path.join(self.work_dir, 'data/'))
+        emulator = request_handler.get_handler(attack_event.matched_pattern)
+        emulator.handle(attack_event)
+        # Logging the event
+        if self.profiler_available:
+            self.profiler.handle_event(attack_event)
+        self.post_queue.put(attack_event)
+
+        header = attack_event.http_request.get_response_header()
+        body = attack_event.http_request.get_response_body()
+        return header, body
