@@ -16,6 +16,7 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import re
+import warnings
 from datetime import datetime
 
 import logging
@@ -38,7 +39,8 @@ class Database(object):
             raise Exception("Invalid Mongo URI. Database name must be specified.")
 
         try:
-            self.client = MongoClient(connection_string)
+            with warnings.catch_warnings(record=True):
+                self.client = MongoClient(connection_string)
             self.db = self.client[uri_dict['database']]
         except:
             logger.exception("Unable to connect to MongoDB service.")
@@ -51,7 +53,7 @@ class Database(object):
         url_list = []
 
         data = self.db.events.find({'pattern': pattern})
-        data = list(data.distinct('request.url'))
+        data = list(data.distinct('request_url'))
 
         self.num_distinct_results = len(data)
 
@@ -66,7 +68,7 @@ class Database(object):
         Selects URL from main database filterned by name.
         """
         regx = re.compile(starts_with + ".*", re.IGNORECASE)
-        urls = list(self.db.events.find({'request.url': regx}))
+        urls = list(self.db.events.find({'request_url': regx}))
         return urls
 
     def insert_dorks(self, insert_list):
