@@ -37,15 +37,18 @@ class DorkPageGenerator(object):
     Responsible for maintenance of dork pages and collection of dorks from requests.
     """
 
-    def __init__(self, database_instance,
+    def __init__(self,
+                 database_instance,
                  dorks_file_processor_instance,
                  cluster_instance,
-                 dork_service=False,
-                 data_dir=os.getcwd(),
+                 data_dir,
+                 pages_dir=None,
                  mnem_service_instance=None):
-        self.dork_service = dork_service
         self.database = database_instance
-        self.pages_path = os.path.join(data_dir, 'dork_pages')
+        if not pages_dir:
+            self.pages_path = os.path.join(data_dir, 'dork_pages')
+        else:
+            self.pages_path = os.path.join(pages_dir, 'dork_pages')
         if not os.path.isdir(self.pages_path):
             os.mkdir(self.pages_path, 0770)
         self.dork_file_processor = dorks_file_processor_instance
@@ -57,7 +60,7 @@ class DorkPageGenerator(object):
             logger.info("Bootstrapping dork database.")
             self.bootstrap_dorkdb()
         self.enabled = True
-        self.surface_creator = create_surface.SurfaceCreator()
+        self.surface_creator = create_surface.SurfaceCreator(data_dir=data_dir)
 
     def prepare_text(self):
         line_list = []
@@ -136,10 +139,10 @@ class DorkPageGenerator(object):
     def collect_dork(self, attack_event):
         if attack_event.matched_pattern != "unknown":
             try:
-                dork = attack_event.parsed_request.url.split('?')[0]
+                dork = attack_event.http_request.path.split('?')[0]
                 self.database.insert_dorks([{'table': "inurl", 'content': dork}])
             except Exception as e:
-                logger.exception("Parsed_request split error: {0}".format(e))
+                logger.exception("http_request split error: {0}".format(e))
 
     def bootstrap_dorkdb(self):
         ignore = ()
