@@ -27,13 +27,13 @@ package_directory = os.path.dirname(os.path.abspath(__file__))
 def _get_logger_names(path=os.path.join(package_directory, 'reporting/auxiliary')):
     names = os.listdir(path)
     for name in reversed(names):
-        if (name == 'base_logger.py' or name == '.git'
-            or ".pyc" in name or name == '__init__.py'):
+        if (name == 'base_logger.py' or name == '.pyc'
+            or name == '__init__.py'):
             names.remove(name)
     return names
 
 
-def get_aux_loggers(create_tables=True):
+def get_aux_loggers(data_dir, create_tables=True):
     loggers = []
     try:
         BaseLogger()
@@ -46,7 +46,7 @@ def get_aux_loggers(create_tables=True):
         return None
     else:
         for logger_class in logger_classes:
-            logger_instance = logger_class()
+            logger_instance = logger_class(data_dir)
             if logger_instance.options['enabled']:
                 loggers.append(logger_instance)
         return loggers
