@@ -56,7 +56,7 @@ class LogSURFcertIDS(BaseLogger):
 
     """
 
-    def __init__(self, config="glastopf.cfg"):
+    def __init__(self, data_dir, config="glastopf.cfg"):
         conf_parser = ConfigParser()
         conf_parser.read(config)
         self.options = {
@@ -130,7 +130,7 @@ class LogSURFcertIDS(BaseLogger):
                                attackid,
                                str(attack_event.sensor_addr[0]),
                                self.options["ptype_request"],
-                               attack_event.parsed_request.url
+                               attack_event.http_request.url
                            )
             )
             cursor.execute("""
@@ -140,7 +140,7 @@ class LogSURFcertIDS(BaseLogger):
                                attackid,
                                str(attack_event.sensor_addr[0]),
                                self.options["ptype_referer"],
-                               attack_event.parsed_request.header.get('Referer', 'None')
+                               attack_event.http_request.header.get('Referer', 'None')
                            )
             )
             cursor.execute("""
@@ -150,7 +150,7 @@ class LogSURFcertIDS(BaseLogger):
                                attackid,
                                str(attack_event.sensor_addr[0]),
                                self.options["ptype_useragent"],
-                               attack_event.parsed_request.header.get('User-Agent', 'None')
+                               attack_event.http_request.header.get('User-Agent', 'None')
                            )
             )
             cursor.execute("""
@@ -160,7 +160,7 @@ class LogSURFcertIDS(BaseLogger):
                                attackid,
                                str(attack_event.sensor_addr[0]),
                                self.options["ptype_host"],
-                               attack_event.parsed_request.header.get('Host', 'None')
+                               attack_event.http_request.header.get('Host', 'None')
                            )
             )
             cursor.execute("""
