@@ -5,11 +5,13 @@ import subprocess
 import threading
 from functools import partial
 import os
+import logging
 
 VERSION = '1.0'
 
 """Inspired by Jose Nazario's PHP sandbox, extended/modified by Lukas Rist"""
 
+logger = logging.getLogger(__name__)
 
 def killer(proc, secs):
     time.sleep(secs)
@@ -22,7 +24,7 @@ def killer(proc, secs):
 def sandbox(script, secs, data_dir):
     proc = None
     try:
-        proc = subprocess.Popen(["php5", os.path.join(data_dir, "sandbox.php"),
+        proc = subprocess.Popen(["php", os.path.join(data_dir, "sandbox.php"),
                                  os.path.join(data_dir, "files", script)],
                                 shell=False,
                                 stdin=subprocess.PIPE,
@@ -30,16 +32,16 @@ def sandbox(script, secs, data_dir):
                                 stderr=subprocess.PIPE,
         )
     except Exception as e:
-        print "PARENT : error executing the sandbox:", e
+        logger.exception("Error executing the sandbox:".format(e))
     stdout_value = ""
     stderr_value = ""
     try:
         threading.Thread(target=partial(killer, proc, secs)).start()
         stdout_value, stderr_value = proc.communicate()
     except Exception as e:
-        print "Sandbox communication error:", e
+        logger.exception("Sandbox communication error:".format(e))
     else:
-        print "Successfully parsed with sandbox"
+        logger.info("File successfully parsed with sandbox.")
     return stdout_value
 
 
